<?php
/**
 * Adds custom widgets
 *
 * @package adsoft Widget Pack
 * @version 1.0
 */

/**
 * Helper function that updates fields in the dashboard form
 *
 * @since adsoft Widget Pack 1.0
 */
function adsoft_widgets_updated_field_value( $widget_field, $new_field_value ) {

	extract( $widget_field );
	
	// Allow only integers in number fields
	if( $adsoft_widgets_field_type == 'number' ) {
		return absint( $new_field_value );
		
	// Allow some tags in textareas
	} elseif( $adsoft_widgets_field_type == 'textarea' ) {
		// Check if field array specifed allowed tags
		if( !isset( $adsoft_widgets_allowed_tags ) ) {
			// If not, fallback to default tags
			$adsoft_widgets_allowed_tags = '<p><strong><em><a>';
		}
		return strip_tags( $new_field_value, $adsoft_widgets_allowed_tags );
		
	// No allowed tags for all other fields
	} else {
		return strip_tags( $new_field_value );
	}

}

/**
 * Include helper functions that display widget fields in the dashboard
 *
 * @since adsoft Widget Pack 1.0
 */
get_template_part('includes/widgets/widget', 'fields');

/**
 * Register Post Preview Widget
 *
 * @since adsoft Widget Pack 1.0
 */
get_template_part('includes/widgets/widget', 'preview-post');

/**
 * Register Social Icons Widget
 *
 * @since adsoft Widget Pack 1.0
 */
get_template_part('includes/widgets/widget', 'social-icons');

/**
 * Media Embed Widget
 *
 * @since adsoft Widget Pack 1.0
 */
get_template_part('includes/widgets/widget', 'media-embed'); 

/**
 * Subscribe Widget
 *
 * @since adsoft Widget Pack 1.0
 */
get_template_part('includes/widgets/widget', 'subscribe'); 

/**
 * Tabber Widget
 *
 * @since adsoft Widget Pack 1.0
 */
 get_template_part('includes/widgets/widget', 'tabs'); 