<?php
/***
 * Setup Theme Options
 *
 * Includes all settings from the /includes/options/settings/ folder
 * (setting arrays are splitted in multiple files for reasons of clarity)
 *
 * Defines the theme options array containing all tabs, sections and settings.
 * Contain functions to display the welcome screen and sidebar content on options screen.
 *
 */

// Include all Setting Files

get_template_part('includes/options/settings/settings', 'general');
get_template_part('includes/options/settings/settings', 'colors');
get_template_part('includes/options/settings/settings', 'fonts');
get_template_part('includes/options/settings/settings', 'about');
get_template_part('includes/options/settings/settings', 'frontpage');


// Creates theme options array with all sections and settings
function adsoft_options_array() {

	/* Section and Setting functions come from setting files included above */
	
	$theme_options = array();
	
	$theme_options['general'] = array(
			"name" => __('General', 'adsoft_language'),
			"sections" => adsoft_sections_general(),
			"settings" => adsoft_settings_general());
	
	$theme_options['colors'] = array(
			"name" => __('Colors', 'adsoft_language'),
			"sections" => adsoft_sections_colors(),
			"settings" => adsoft_get_colors_settings());

	$theme_options['fonts'] = array(
			"name" => __('Fonts', 'adsoft_language'),
			"sections" => adsoft_sections_fonts(),
			"settings" => adsoft_settings_fonts());

	$theme_options['about'] = array(
			"name" => __('About', 'adsoft_language'),
			"sections" => adsoft_sections_about(),
			"settings" => adsoft_settings_about());		
			
	$theme_options['frontpage'] = array(
			"name" => __('Front Page', 'adsoft_language'),
			"sections" => adsoft_sections_frontpage(),
			"settings" => adsoft_settings_frontpage());	
	
	return $theme_options;
}

	// Get available default Fonts
	function adsoft_get_web_fonts() { 
		
		// Default font array
		$adsoft_fonts = array(
			'Abril Fatface' => 'Abril Fatface',
			'Arial' => 'Arial',
			'Audiowide' => 'Audiowide',
			'Arvo' => 'Arvo',
			'Carme' => 'Carme',
			'Courier New' => 'Courier New',
			'Droid Sans' => 'Droid Sans',
			'Helvetica' => 'Helvetica',
			'Impact' => 'Impact',
			'Josefin Slab' => 'Josefin Slab',
			'Lato' => 'Lato',
			'Lobster' => 'Lobster',
			'Luckiest Guy' => 'Luckiest Guy',
			'Jockey One' => 'Jockey One',
			'Maven Pro' => 'Maven Pro',
			'Modern Antiqua' => 'Modern Antiqua',
			'Niconne' => 'Niconne',
			'Nobile' => 'Nobile',
			'Old Standard TT' => 'Old Standard TT',
			'Open Sans' => 'Open Sans',
			'Orbitron' => 'Orbitron',	
			'Oswald' => 'Oswald',
			'Permanent Marker' => 'Permanent Marker',
			'PT Sans' => 'PT Sans',
			'PT Serif' => 'PT Serif',
			'Russo One' => 'Russo One',
			'Share' => 'Share',
			'Tahoma' => 'Tahoma',
			'Tangerine' => 'Tangerine',
			'Trebuchet MS' => 'Trebuchet MS',			
			'Ubuntu' => 'Ubuntu',
			'Vollkorn' => 'Vollkorn',
			'Verdana' => 'Verdana',
			'Yanone Kaffeesatz' => 'Yanone Kaffeesatz');			
		// Add fonts installed by User
		$options = get_option('adsoft_options');
		if ( isset($options['adsoft_fonts_installed']) and $options['adsoft_fonts_installed'] != '' ) :
			
			$fonts = explode(";", $options['adsoft_fonts_installed']);
			foreach ( $fonts as $value) {
				$adsoft_fonts[trim($value)] = trim($value);
			}
			asort($adsoft_fonts);
		endif;
		
		return $adsoft_fonts; 
	}
	

// Display Welcome Page
function adsoft_options_welcome_page() { 
	$theme_data = wp_get_theme();
?>
	<div id="tux_welcome">
		<h3><?php _e('Thank you for installing this theme!', 'adsoft_language'); ?></h3>
		<div class="container">
			<h1><?php _e('Welcome to', 'adsoft_language'); ?> <?php echo $theme_data->Name; ?></h1>
			<div class="tux_intro">
					<p>
			<?php printf( __( 'adsoft is strong, but come with simple theme options. Easy to setup, just few things that you should know ( You may already :D ).', 'adsoft_language' ), '<strong>', '</strong>' ); ?>
		</p>

		<h1>
			<?php _e( 'adsoft Quick Start Guide ;', 'adsoft_language' ); ?>
		</h1>
		<ul>
		    <li>
			   <?php printf( __( 'Don&#8217;t use automatically display the frontpage template on HOME page on fresh install,  have at least 20 posts. If you are trying adsoft on a local server or a test site, you can %sdownload test data%s and import it to your test site.', 'adsoft_language' ), '<a title="'.__( 'Download WordPress test data', 'adsoft_language' ).'" href="http://codex.wordpress.org/Theme_Unit_Test">', '</a>' ); ?>
		    </li>
			<li><?php printf( __( 'adsoft has 3 menus location; Top Left Menu, Main Menu and Footer Menu. Set them up at %s.', 'adsoft_language' ), '<em><a href="nav-menus.php">'.__( 'Appearance', 'default' ).' &rarr; '.__( 'Menus', 'default' ).'</a></em>' ); ?>
			</li>
	    	<li><?php printf( __( 'Use the "%s" option in your posts for thumbnails to appear. Install the %s plugin.  Installing the plugin is not enough, you have to go to %s and click %s (this is what You do every time you instal new theme). Make sure that all image in your site is ready on your media library (if not, you must instal %s and import all image to your media library).', 'adsoft_language' ), __( 'Set featured image', 'default' ), '<a href="http://wordpress.org/plugins/ajax-thumbnail-rebuild/">AJAX Thumbnail Rebuild</a>', '<em><a href="tools.php?page=ajax-thumbnail-rebuild">'.__( 'Tools', 'default' ).' &rarr; AJAX Thumbnail Rebuild</a></em>', '<strong>Rebuild All Thumbnails</strong>', '<a href="http://wordpress.org/plugins/import-external-images/">Import External Images</a>' ); ?>
			</li>
			<li><?php printf( __( 'adsoft has %s handy widgets area and come with:', 'adsoft_language' ), '<strong>7</strong>' ); ?>
                <ol>
			        <li><?php _e( 'adsoft Tabs', 'adsoft_language' ); ?>
					<li><?php _e( 'adsoft Preview Post', 'adsoft_language' ); ?>
					<li><?php _e( 'adsoft Social Icons', 'adsoft_language' ); ?>
					<li><?php _e( 'adsoft Media Embed', 'adsoft_language' ); ?>
					<li><?php _e( 'adsoft Subscribe', 'adsoft_language' ); ?>
				</ol>	
				<?php printf( __( 'Go to %s to find them.', 'adsoft_language' ), '<em><a href="widgets.php">'.__( 'Appearance', 'default' ).' &rarr; '.__( 'Widgets', 'default' ).'</a></em>' ); ?>
			</li>
		</ul>

		<p>
			<?php _e( 'I think that is all. If you are having problems it might be something to do with the adsoft theme, or with something else entirely. Of course you can contact me anytime.', 'adsoft_language' ); ?>
		</p>
		<p style="text-align: center;">
			<?php _e( 'You need to remove footer copyright links? Please by me a lipstick :D ', 'adsoft_language' ); ?>
		</p>
		<div style="text-align: center; margin:0 auto;">
		<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
			<input type="hidden" name="cmd" value="_s-xclick">
			<input type="hidden" name="hosted_button_id" value="JTHPQEWPT4ZPY">
			<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
			<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
		</form>
		</div>
		<p style="text-align: center;">
			<em><?php _e( 'Zifan Safira', 'adsoft_language' ); ?>
			</em>
		</p>
			</div>
		</div>
		</div>

<?php
}
?>